<!-- Use this file to provide workspace-specific custom instructions to Copilot. For more details, visit https://code.visualstudio.com/docs/copilot/copilot-customization#_use-a-githubcopilotinstructionsmd-file -->

This is a FastMCP Server project for Microsoft Fabric Admin. Use https://github.com/modelcontextprotocol/fastmcp as the reference for MCP server implementation.
- Expose Microsoft Fabric admin operations as MCP tools.
- Use DefaultAzureCredential to allow for secure Azure API access to perform Fabric operations.